@@ -319,20 +319,21 @@ class JobPool(object):
     """
     Abstracts away boilerplate of submitting and collecting jobs
 
+    This is a basic wrapper around :class:`ubelt.util_futures.Executor` that
+    simplifies the most basic case.
+
     Example:
         >>> import ubelt as ub
         >>> def worker(data):
         >>>     return data + 1
         >>> pool = ub.JobPool('thread', max_workers=16)
-        >>> with pool:
-        >>>     for data in ub.ProgIter(range(10), desc='submit jobs'):
-        >>>         job = pool.submit(worker, data)
-        >>>     final = []
-        >>>     for job in ub.ProgIter(pool.as_completed(), total=len(pool), desc='collect jobs'):
-        >>>         info = job.result()
-        >>>         final.append(info)
+        >>> for data in ub.ProgIter(range(10), desc='submit jobs'):
+        >>>     pool.submit(worker, data)
+        >>> final = []
+        >>> for job in pool.as_completed(desc='collect jobs'):
+        >>>     info = job.result()
+        >>>     final.append(info)
         >>> print('final = {!r}'.format(final))
-        >>> pool.shutdown()
     """
     def __init__(self, mode='thread', max_workers=0):
         self.executor = Executor(mode=mode, max_workers=max_workers)
@@ -345,6 +346,15 @@ class JobPool(object):
         """
         Submit a job managed by the pool
 
+        Args:
+            func (Callable[..., Any]):
+                A callable that will take as many arguments as there are passed
+                iterables.
+
+            *args : positional arguments to pass to the function
+
+            *kwargs : keyword arguments to pass to the function
+
         Returns:
             concurrent.futures.Future:
                 a future representing the job
@@ -364,12 +374,27 @@ class JobPool(object):
     def __exit__(self, a, b, c):
         self.executor.__exit__(a, b, c)
 
-    def as_completed(self):
+    # TODO: add some way to clear completed jobs?
+    # def clear_completed
+
+    def as_completed(self, timeout=None, desc=None, progkw=None):
         """
         Generates completed jobs in an arbitrary order
 
+        Args:
+            timeout (float | None):
+                Specify the the maximum number of seconds to wait for a job.
+
+            desc (str | None):
+                if specified, reports progress with a
+                :class:`ubelt.progiter.ProgIter` object.
+
+            progkw (dict | None):
+                extra keyword arguments to :class:`ubelt.progiter.ProgIter`.
+
         Yields:
-            concurrent.futures.Future
+            concurrent.futures.Future:
+                The completed future object containing the results of a job.
 
         CommandLine:
             xdoctest -m ubelt.util_futures JobPool.as_completed
@@ -393,7 +418,14 @@ class JobPool(object):
             ...     pass
             >>> pool.shutdown()
         """
-        for job in as_completed(self.jobs):
+        import ubelt as ub
+        job_iter = as_completed(self.jobs)
+        if desc is not None:
+            if progkw is None:
+                progkw = {}
+            job_iter = ub.ProgIter(
+                job_iter, desc=desc, total=len(self.jobs), **progkw)
+        for job in job_iter:
             yield job
 
     def __iter__(self):
